@@ -1,4 +1,5 @@
 import collections
+import importlib.metadata
 import logging
 import optparse
 import os
@@ -13,9 +14,9 @@ try:
 except ImportError:  # pragma: no cover
     from pip._internal.download import PipSession
 from pip._internal.req.req_file import parse_requirements
-from pip._internal.utils.misc import get_installed_distributions
 
 from pip_check_reqs import common
+from pip_check_reqs.common import version_info
 
 log = logging.getLogger(__name__)
 
@@ -27,7 +28,11 @@ def find_missing_reqs(options, requirements_filename):
 
     # 2. find which packages provide which files
     installed_files = {}
-    all_pkgs = (pkg.project_name for pkg in get_installed_distributions())
+    all_pkgs = (
+        dist.metadata["Name"] for dist
+        in importlib.metadata.distributions()
+    )
+
     for package in search_packages_info(all_pkgs):
         if isinstance(package, dict):  # pragma: no cover
             package_name = package['name']
@@ -102,8 +107,6 @@ def find_missing_reqs(options, requirements_filename):
 
 
 def main():
-    from pip_check_reqs import __version__
-
     usage = 'usage: %prog [options] files or directories'
     parser = optparse.OptionParser(usage)
     parser.add_option("--requirements-file",
@@ -136,7 +139,7 @@ def main():
                       action="store_true",
                       default=False,
                       help="be *really* verbose")
-    parser.add_option("--version",
+    parser.add_option("-V", "--version",
                       dest="version",
                       action="store_true",
                       default=False,
@@ -145,7 +148,8 @@ def main():
     (options, args) = parser.parse_args()
 
     if options.version:
-        sys.exit(__version__)
+        print(version_info())
+        sys.exit(0)
 
     if not args:
         parser.error("no source files or directories specified")
@@ -166,7 +170,7 @@ def main():
     log.setLevel(level)
     common.log.setLevel(level)
 
-    log.info('using pip_check_reqs-%s from %s', __version__, __file__)
+    log.info(version_info())
 
     missing = find_missing_reqs(
         options=options,
